@@ -3,7 +3,7 @@ import requests
 import random
 import string
 import os
-from llama_index import download_loader
+#from llama_index import download_loader
 from pathlib import Path
 
 class KnowledgeBase:
@@ -188,18 +188,19 @@ def read_file(file_path: str, file_type: str = None):
         "docx": "DocxReader",
         "md": "MarkdownReader"
     }
+
+    """elif file_type in list(reader_names.keys()):
+        Reader = download_loader(reader_names[file_type])
+        loader = Reader()
+        documents = loader.load_data(file=Path(file_path))
+        content = documents[0].text
+        return content"""
     
     if file_type == "txt":
         with open(file_path, 'r') as f:
             # read the file and convert it to a string
             content = f.read()
             return content
-    elif file_type in list(reader_names.keys()):
-        Reader = download_loader(reader_names[file_type])
-        loader = Reader()
-        documents = loader.load_data(file=Path(file_path))
-        content = documents[0].text
-        return content
     else:
         return None
 
