@@ -8,7 +8,7 @@ import base64
 import os
 
 # initialize variables
-BASE_URL = 'https://api.superpowered.ai/v1'
+BASE_URL = 'https://api.superpowered.ai/v1/'
 
 def init(api_key_id: str, api_key_secret: str, verbose: bool = False):
     """
@@ -40,4 +40,4 @@ def _format_http_response(resp: requests.Response):
     return {
         'http_code': resp.status_code,
         'body': resp.json()
-    }
\ No newline at end of file
+    }
